@@ -8,8 +8,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEO_OIDMAP_H__
-#define __KLEO_OIDMAP_H__
+#pragma once
 
 #include "kleo_export.h"
 
@@ -38,4 +37,3 @@ static const unsigned int numOidMaps = sizeof oidmap / sizeof * oidmap;
 
 KLEO_EXPORT const char *oidForAttributeName(const QString &attr);
 
-#endif // __KLEO_OIDMAP_H__
